@@ -9,8 +9,12 @@ from runway.context import Context
 from runway.core.providers import aws
 from runway.hooks.staticsite.util import get_hash_of_files
 from runway.module.serverless import get_src_hash
-from runway.s3_util import (download, get_matching_s3_keys,
-                            purge_and_delete_bucket, purge_bucket)
+from runway.s3_util import (
+    download,
+    get_matching_s3_keys,
+    purge_and_delete_bucket,
+    purge_bucket,
+)
 from runway.util import change_dir, find_cfn_output
 
 
