@@ -9,9 +9,14 @@ from troposphere import Output, Parameter, Ref, Template
 
 from runway.variables import Variable
 
-from ..exceptions import (InvalidUserdataPlaceholder, MissingVariable,
-                          UnresolvedVariable, UnresolvedVariables,
-                          ValidatorError, VariableTypeRequired)
+from ..exceptions import (
+    InvalidUserdataPlaceholder,
+    MissingVariable,
+    UnresolvedVariable,
+    UnresolvedVariables,
+    ValidatorError,
+    VariableTypeRequired,
+)
 from ..util import read_value_from_path
 from .variables.types import CFNType, TroposphereType
 
@@ -287,10 +292,12 @@ class Blueprint(object):
 
         Args:
             name (str): A name for the blueprint.
-            context (:class:`runway.cfngin.context.Context`): the context the blueprint
-                is being executed under.
-            mappings (dict, optional): Cloudformation Mappings to be used in the
-                template.
+            context (:class:`runway.cfngin.context.Context`): Context
+                the blueprint is being executed under.
+            mappings (dict, optional): CloudFormation Mappings to be used
+                in the template.
+            description (str): Used to describe the resulting
+                CloudFormation template.
 
         """
         self.name = name
