@@ -10,8 +10,14 @@ import yaml
 from schematics import Model
 from schematics.exceptions import BaseError as SchematicsError
 from schematics.exceptions import UndefinedValueError, ValidationError
-from schematics.types import (BaseType, BooleanType, DictType, ListType,
-                              ModelType, StringType)
+from schematics.types import (
+    BaseType,
+    BooleanType,
+    DictType,
+    ListType,
+    ModelType,
+    StringType,
+)
 from six import text_type
 
 from runway.util import DOC_SITE
@@ -406,7 +412,7 @@ class Stack(Model):
 
 
 class Config(Model):
-    """This is the Python representation of a CFNgin config file.
+    """Python representation of a CFNgin config file.
 
     This is used internally by CFNgin to parse and validate a yaml formatted
     CFNgin configuration file, but can also be used in scripts to generate a
