@@ -12,7 +12,7 @@ import yaml
 from botocore.config import Config
 from six.moves import urllib
 
-from runway.util import DOC_SITE
+from runway.util import DOC_SITE, JsonEncoder
 
 from ... import exceptions
 from ...actions.diff import DictValue, diff_parameters
@@ -75,14 +75,15 @@ def get_output_dict(stack):
         stack.
 
     """
-    outputs = {}
     if not stack.get('Outputs'):
-        return outputs
-
-    for output in stack['Outputs']:
-        LOGGER.debug("    %s %s: %s", stack['StackName'], output['OutputKey'],
-                     output['OutputValue'])
-        outputs[output['OutputKey']] = output['OutputValue']
+        return {}
+    outputs = {
+        output['OutputKey']: output['OutputValue']
+        for output in stack.get('Outputs', [])
+    }
+    LOGGER.debug(
+        '%s stack outputs: %s', stack['StackName'], json.dumps(outputs)
+    )
     return outputs
 
 
@@ -1013,6 +1014,7 @@ class Provider(BaseProvider):
         stack policy is passed in.
 
         Args:
+            fqn (str): Fully qualified name of the stack.
             stack_policy (:class:`runway.cfngin.providers.base.Template`):
                 A template object representing a stack policy.
 
@@ -1276,7 +1278,7 @@ class Provider(BaseProvider):
         if isinstance(template, str):  # handle yaml templates
             template = parse_cloudformation_template(template)
 
-        return json.dumps(template), parameters
+        return json.dumps(template, cls=JsonEncoder), parameters
 
     def get_stack_changes(self, stack, template, parameters, tags):
         """Get the changes from a ChangeSet.
