@@ -1,11 +1,15 @@
 """Refresh authorization token for new credentials."""
-
 import logging
 import traceback
-from urllib.parse import parse_qs # noqa pylint: disable=no-name-in-module, import-error
+from urllib.parse import parse_qs  # noqa pylint: disable=E
 
-from shared import (create_error_html, extract_and_parse_cookies, get_config,  # noqa pylint: disable=import-error
-                    get_cookie_headers, http_post_with_retry)
+from shared import (  # noqa pylint: disable=import-error
+    create_error_html,
+    extract_and_parse_cookies,
+    get_config,
+    get_cookie_headers,
+    http_post_with_retry,
+)
 
 LOGGER = logging.getLogger(__name__)
 CONFIG = get_config()
@@ -14,8 +18,10 @@ CONFIG = get_config()
 def handler(event, _context):
     """Handle the authorization refresh.
 
-    Keyword Args:
-        event: The Lambda Event
+    Args:
+        event: The Lambda Event.
+        _context (Any): Lambda context object.
+
     """
     request = event['Records'][0]['cf']['request']
     domain_name = request['headers']['host'][0]['value']
@@ -117,11 +123,12 @@ def validate_refresh_request(current_nonce,
                              tokens):
     """Validate that nonce and tokens are present.
 
-    Keyword Args:
-        current_nonce (str): The current nonce code
-        original_nonce (str): The original nonce code
+    Args:
+        current_nonce (str): The current nonce code.
+        original_nonce (str): The original nonce code.
         tokens (Dict[str, str]): A dictionary of all the token_types
-            and their corresponding token values (id, auth, refresh)
+            and their corresponding token values (id, auth, refresh).
+
     """
     if not original_nonce:
         msg = "Your browser didn't send the nonce cookie along, " + \
