@@ -2,8 +2,9 @@
 
 .. _lookup arguments:
 
+****************
 Lookup Arguments
-^^^^^^^^^^^^^^^^
+****************
 
 Arguments can be passed to Lookups to effect how they function.
 
@@ -27,7 +28,7 @@ that all Lookups accept.
 .. _Common Lookup Arguments:
 
 Common Lookup Arguments
-~~~~~~~~~~~~~~~~~~~~~~~
+=======================
 
 **default (Any)**
     If the Lookup is unable to find a value for the provided query, this
@@ -80,7 +81,7 @@ Common Lookup Arguments
 .. code-block:: yaml
 
   deployments:
-    - environments:
+    - parameters:
         some_variable: ${var some_value::default=my_value}
         comma_list: ${var my_list::default=undefined, transform=str}
 
@@ -89,8 +90,14 @@ import json
 import logging
 # python2 supported pylint is unable to load this when in a venv
 from distutils.util import strtobool  # pylint: disable=E
-from typing import (TYPE_CHECKING, Any, Dict,  # noqa: F401 pylint: disable=W
-                    Optional, Tuple, Union)
+from typing import (  # noqa: F401 pylint: disable=W
+    TYPE_CHECKING,
+    Any,
+    Dict,
+    Optional,
+    Tuple,
+    Union,
+)
 
 import yaml
 from six import string_types
@@ -381,7 +388,7 @@ class LookupHandler(object):
 
         Args:
             value: The value to be transformed into a string.
-            delimited: Used when transforming a list like object into a string
+            delimiter: Used when transforming a list like object into a string
                 to join each element together.
 
         """
