@@ -1,17 +1,18 @@
-from aws_cdk import (
-    aws_iam as iam,
-    aws_sqs as sqs,
-    aws_sns as sns,
-    aws_sns_subscriptions as subs,
-    core
-)
+"""Hello stack."""
+from aws_cdk import aws_iam as iam
+from aws_cdk import aws_sns as sns
+from aws_cdk import aws_sns_subscriptions as subs
+from aws_cdk import aws_sqs as sqs
+from aws_cdk import core
 
 from .hello_construct import HelloConstruct
 
 
 class MyStack(core.Stack):
+    """My stack."""
 
     def __init__(self, scope: core.Construct, id: str, **kwargs) -> None:
+        """Instantiate class."""
         super().__init__(scope, id, **kwargs)
 
         queue = sqs.Queue(
