@@ -1,19 +1,33 @@
 """Runway variables."""
 import logging
 import re
-from typing import (TYPE_CHECKING,  # noqa: F401 pylint: disable=W
-                    Any, Dict, Iterable, Iterator, List, Optional, Set, Type,
-                    Union, cast)
+from typing import (  # noqa: F401 pylint: disable=W
+    TYPE_CHECKING,
+    Any,
+    Dict,
+    Iterable,
+    Iterator,
+    List,
+    Optional,
+    Set,
+    Type,
+    Union,
+    cast,
+)
 
 from six import string_types
 
-from .cfngin.exceptions import (FailedLookup, FailedVariableLookup,
-                                InvalidLookupCombination,
-                                InvalidLookupConcatenation, UnknownLookupType,
-                                UnresolvedVariable, UnresolvedVariableValue)
+from .cfngin.exceptions import (
+    FailedLookup,
+    FailedVariableLookup,
+    InvalidLookupCombination,
+    InvalidLookupConcatenation,
+    UnknownLookupType,
+    UnresolvedVariable,
+    UnresolvedVariableValue,
+)
 from .cfngin.lookups.registry import CFNGIN_LOOKUP_HANDLERS
-from .lookups.handlers.base import \
-    LookupHandler  # noqa: F401 pylint: disable=unused-import
+from .lookups.handlers.base import LookupHandler  # noqa: F401 pylint: disable=W
 from .lookups.registry import RUNWAY_LOOKUP_HANDLERS
 
 # python2 supported pylint sees this is cyclic even though its only for type checking
@@ -49,6 +63,7 @@ class Variable(object):
         Args:
             name: Name of the variable (directive/key).
             value: The variable itself.
+            variable_type: Type of variable (cfngin|runway).
 
         """
         self.name = name
@@ -181,6 +196,7 @@ class VariableValue(object):
 
         Args:
             input_object: The objected defined as the value of a variable.
+            variable_type: Type of variable (cfngin|runway).
 
         """
         if isinstance(input_object, list):
@@ -350,6 +366,7 @@ class VariableValueList(VariableValue, list):
 
         Args:
             input_object: The objected defined as the value of a variable.
+            variable_type: Type of variable (cfngin|runway).
 
         """
         acc = [
@@ -435,6 +452,7 @@ class VariableValueDict(VariableValue, dict):
 
         Args:
             input_object: The objected defined as the value of a variable.
+            variable_type: Type of variable (cfngin|runway).
 
         """
         acc = {
@@ -574,6 +592,8 @@ class VariableValueLookup(VariableValue):
         Args:
             lookup_name: Name of the invoked lookup
             lookup_data: Data portion of the lookup
+            handler: Lookup handler that will be use to resolve the value.
+            variable_type: Type of variable (cfngin|runway).
 
         """
         self._resolved = False
@@ -679,10 +699,16 @@ class VariableValueLookup(VariableValue):
 
     def _resolve(self, value):
         # type: (Any) -> None
-        """Set _value and _resolved from the result of resolve()."""
+        """Set _value and _resolved from the result of resolve().
+
+        Args:
+            value: Resolved value of the variable.
+
+        """
         self._value = value
         self._resolved = True
 
+    # TODO Remove during the next major release.
     def _resolve_legacy(self, context, provider):
         """Resolve legacy lookups.
 
@@ -694,9 +720,6 @@ class VariableValueLookup(VariableValue):
         this method comes it. It can handle legacy Stacker function lookups
         and those that don't support accept more then 3 args.
 
-        TODO:
-            Remove during the next major release.
-
         """
         if isinstance(self.handler, type):
             import warnings  # pylint: disable=import-outside-toplevel
