@@ -20,6 +20,6 @@ class GitTester(unittest.TestCase):
         self.assertEqual(fetched, '/')
 
     def test_sanitize_git_path(self):
-        """Ensure git path is property sanitized"""
+        """Ensure git path is property sanitized."""
         path = Git().sanitize_git_path('git://github.com/onicagroup/runway.git')
         self.assertEqual(path, 'github.com_onicagroup_runway')
