@@ -17,12 +17,12 @@ class SourceTester(unittest.TestCase):
         self.assertRaises(NotImplementedError, source.fetch)
 
     def test_when_no_cache_dir_parameter_in_config(self):
-        """The default when no cache_dir is passed in the config"""
+        """The default when no cache_dir is passed in the config."""
         source = Source({})
         self.assertEqual(source.cache_dir, os.path.expanduser('~/.runway_cache'))
 
     def test_a_cache_directory_is_created(self):
-        """Ensure a cache directory is created"""
+        """Ensure a cache directory is created."""
         source = Source({})
         self.assertTrue(os.path.isdir(source.cache_dir))
 
